Learn R Programming

tern.rbmi (version 0.1.6)

h_tidy_pool: Helper function to produce data frame with results of pool for a single visit

Description

[Experimental]

Usage

h_tidy_pool(x)

Value

Data frame with results of pool for a single visit.

Arguments

x

(pool) is a list of pooled object from rbmi analysis results. This list includes analysis results, confidence level, hypothesis testing type.

Examples

Run this code
data("rbmi_test_data")
pool_obj <- rbmi_test_data

h_tidy_pool(pool_obj$pars[1:3])

Run the code above in your browser using DataLab