powered by
h_tidy_pool(x)
Data frame with results of pool for a single visit.
(pool) is a list of pooled object from rbmi analysis results. This list includes analysis results, confidence level, hypothesis testing type.
pool
rbmi
data("rbmi_test_data") pool_obj <- rbmi_test_data h_tidy_pool(pool_obj$pars[1:3])
Run the code above in your browser using DataLab